Learn R Programming

keyclust (version 1.2.5)

cosimilarity_matrix: Returns cosine cosimilarity matrix for the terms generated by keyclust

Description

A function that extracts the cosimilarity matrix for terms generated by keyclust()

Usage

cosimilarity_matrix(x)

Value

An N x N matrix of cosine cosimilarity values, where n is the number of terms in the provided embedding model

Arguments

x

output from keyclust()