powered by
A function that extracts the cosimilarity matrix for terms generated by keyclust()
keyclust()
cosimilarity_matrix(x)
An N x N matrix of cosine cosimilarity values, where n is the number of terms in the provided embedding model
output from keyclust()